// States and alerts
@state-success-text:                  #3c763d;
@state-success-bg:                    #dff0d8;
@state-success-border:                darken(spin(@state-success-bg, -10), 5%);

@state-info-text:                     #31708f;
@state-info-bg:                       #d9edf7;
@state-info-border:                   darken(spin(@state-info-bg, -10), 7%);

@state-warning-text:                  #8a6d3b;
@state-warning-bg:                    #fcf8e3;
@state-warning-border:                darken(spin(@state-warning-bg, -10), 5%);

@state-danger-text:                   #a94442;
@state-danger-bg:                     #f2dede;
@state-danger-border:                 darken(spin(@state-danger-bg, -10), 5%);
