.book-langs-index {
  width: 100%;
  height: 100%;
  padding: 40px 0px;
  margin: 0px;
  overflow: auto;

  @media (max-width: 600px) {
    padding: 0px;
  }

  .inner {
    max-width: 600px;
    width: 100%;

    margin: 0px auto;
    padding: 30px;

    background: #fff;
    border-radius: 3px;

    h3 {
      margin: 0px;
    }

    .languages {
      list-style: none;
      padding: 20px 30px;
      margin-top: 20px;
      border-top: 1px solid #eee;

      .clearfix();

      li {
        width: 50%;
        float: left;
        padding: 10px 5px;
        font-size: 16px;

        @media (max-width: 600px) {
          width: 100%;
          max-width: 100%;
        }
      }
    }
  }
}