.book .book-header .font-settings {
  .font-enlarge {
    line-height: 30px;
    font-size: 1.4em;
  }

  .font-reduce {
    line-height: 30px;
    font-size: 0.8em;
  }

  .font-reset {
    line-height: 30px;
    font-size: 1em;
  }
}
