@import "../markdown-css/mixin.less";

.link-inherit {
    color: inherit;

    &:hover, &:focus {
        color: inherit;
    }
}

.transition-transform(@transition) {
  -webkit-transition: -webkit-transform @transition;
     -moz-transition: -moz-transform @transition;
       -o-transition: -o-transform @transition;
          transition: transform @transition;
}

.hidden {
    display: none;
}

.box-sizing(@value) {
    -moz-box-sizing: @value;
    box-sizing: @value;
}

.text-adjust(@value) {
    text-size-adjust: @value;
    -ms-text-size-adjust: @value;
    -webkit-text-size-adjust: @value;
}

